==> h2o-java-rest-bindings-3.8.2.4-sources.jar: water/bindings/pojos/ModelMetricsBinomialGLMV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class ModelMetricsBinomialGLMV3 extends ModelMetricsBinomialV3 {
    /** residual deviance */
    public double residual_deviance;

    /** null deviance */
    public double null_deviance;

    /** AIC */
    public double AIC;

    /** null DOF */
    public long null_degrees_of_freedom;

    /** residual DOF */
    public long residual_degrees_of_freedom;

    /* INHERITED: The R^2 for this scoring run. 
    public double r2 = 0.0;
     */

    /* INHERITED: The logarithmic loss for this scoring run. 
    public double logloss = 0.0;
     */

    /* INHERITED: The AUC for this scoring run. 
    public double AUC = 0.0;
     */

    /* INHERITED: The Gini score for this scoring run. 
    public double Gini = 0.0;
     */

    /* INHERITED: The class labels of the response. 
    public String[] domain = null;
     */

    /* INHERITED: The Metrics for various thresholds. 
    public TwoDimTableV3 thresholds_and_metric_scores = null;
     */

    /* INHERITED: The Metrics for various criteria. 
    public TwoDimTableV3 max_criteria_and_metric_scores = null;
     */

    /* INHERITED: Gains and Lift table. 
    public TwoDimTableV3 gains_lift_table = null;
     */

    /* INHERITED: The model used for this scoring run. 
    public ModelKeyV3 model = null;
     */

    /* INHERITED: The checksum for the model used for this scoring run. 
    public long model_checksum = 0L;
     */

    /* INHERITED: The frame used for this scoring run. 
    public FrameKeyV3 frame = null;
     */

    /* INHERITED: The checksum for the frame used for this scoring run. 
    public long frame_checksum = 0L;
     */

    /* INHERITED: Optional description for this scoring run (to note out-of-bag, sampled data, etc.) 
    public String description = "";
     */

    /* INHERITED: The category (e.g., Clustering) for the model used for this scoring run. 
    public ModelCategory model_category = null;
     */

    /* INHERITED: The time in mS since the epoch for the start of this scoring run. 
    public long scoring_time = 0L;
     */

    /* INHERITED: Predictions Frame. 
    public FrameV3 predictions = null;
     */

    /* INHERITED: The Mean Squared Error of the prediction for this scoring run. 
    public double MSE = 0.0;
     */

    public ModelMetricsBinomialGLMV3() {
        residual_deviance = 0.0;
        null_deviance = 0.0;
        AIC = 0.0;
        null_degrees_of_freedom = 0L;
        residual_degrees_of_freedom = 0L;
        r2 = 0.0;
        logloss = 0.0;
        AUC = 0.0;
        Gini = 0.0;
        domain = null;
        thresholds_and_metric_scores = null;
        max_criteria_and_metric_scores = null;
        gains_lift_table = null;
        model = null;
        model_checksum = 0L;
        frame = null;
        frame_checksum = 0L;
        description = "";
        model_category = null;
        scoring_time = 0L;
        predictions = null;
        MSE = 0.0;
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}

==> h2o-java-rest-bindings-3.8.2.8-sources.jar: water/bindings/pojos/ModelMetricsBinomialGLMV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class ModelMetricsBinomialGLMV3 extends ModelMetricsBinomialV3 {
    /** residual deviance */
    public double residual_deviance;

    /** null deviance */
    public double null_deviance;

    /** AIC */
    public double AIC;

    /** null DOF */
    public long null_degrees_of_freedom;

    /** residual DOF */
    public long residual_degrees_of_freedom;

    /* INHERITED: The R^2 for this scoring run. 
    public double r2 = 0.0;
     */

    /* INHERITED: The logarithmic loss for this scoring run. 
    public double logloss = 0.0;
     */

    /* INHERITED: The AUC for this scoring run. 
    public double AUC = 0.0;
     */

    /* INHERITED: The Gini score for this scoring run. 
    public double Gini = 0.0;
     */

    /* INHERITED: The mean misclassification error per class. 
    public double mean_per_class_error = 0.0;
     */

    /* INHERITED: The class labels of the response. 
    public String[] domain = null;
     */

    /* INHERITED: The Metrics for various thresholds. 
    public TwoDimTableV3 thresholds_and_metric_scores = null;
     */

    /* INHERITED: The Metrics for various criteria. 
    public TwoDimTableV3 max_criteria_and_metric_scores = null;
     */

    /* INHERITED: Gains and Lift table. 
    public TwoDimTableV3 gains_lift_table = null;
     */

    /* INHERITED: The model used for this scoring run. 
    public ModelKeyV3 model = null;
     */

    /* INHERITED: The checksum for the model used for this scoring run. 
    public long model_checksum = 0L;
     */

    /* INHERITED: The frame used for this scoring run. 
    public FrameKeyV3 frame = null;
     */

    /* INHERITED: The checksum for the frame used for this scoring run. 
    public long frame_checksum = 0L;
     */

    /* INHERITED: Optional description for this scoring run (to note out-of-bag, sampled data, etc.) 
    public String description = "";
     */

    /* INHERITED: The category (e.g., Clustering) for the model used for this scoring run. 
    public ModelCategory model_category = null;
     */

    /* INHERITED: The time in mS since the epoch for the start of this scoring run. 
    public long scoring_time = 0L;
     */

    /* INHERITED: Predictions Frame. 
    public FrameV3 predictions = null;
     */

    /* INHERITED: The Mean Squared Error of the prediction for this scoring run. 
    public double MSE = 0.0;
     */

    public ModelMetricsBinomialGLMV3() {
        residual_deviance = 0.0;
        null_deviance = 0.0;
        AIC = 0.0;
        null_degrees_of_freedom = 0L;
        residual_degrees_of_freedom = 0L;
        r2 = 0.0;
        logloss = 0.0;
        AUC = 0.0;
        Gini = 0.0;
        mean_per_class_error = 0.0;
        domain = null;
        thresholds_and_metric_scores = null;
        max_criteria_and_metric_scores = null;
        gains_lift_table = null;
        model = null;
        model_checksum = 0L;
        frame = null;
        frame_checksum = 0L;
        description = "";
        model_category = null;
        scoring_time = 0L;
        predictions = null;
        MSE = 0.0;
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}
